@@ -7,9 +7,9 @@ templates_path = ['_templates']
 source_suffix = '.rst'
 master_doc = 'index'
 project = u'django-contact-form'
-copyright = u'2007-2016, James Bennett'
-xversion = '1.3'
-release = '1.3'
+copyright = u'2007-2017, James Bennett'
+version = '1.4'
+release = '1.4.2'
 exclude_trees = ['_build']
 pygments_style = 'sphinx'
 html_static_path = ['_static']
